import { defineComponent } from 'vue';
import styles from './index.module.less';
import { NButton, NImage, NSpace, NTooltip } from 'naive-ui';
import iconEdit from '../../images/icon-courseware-edit.png';
import iconDelete from '../../images/icon-courseware-delete.png';
import iconEditName from '../../images/icon-edit-name.png';

export default defineComponent({
  name: 'courseware-type',
  props: {
    item: {
      type: Object,
      default: () => ({})
    },
    /** 是否鼠标滑动时显示显示添加按钮 */
    isHoverShowAdd: {
      type: Boolean,
      default: true
    },
    /** 是否显示添加按钮 */
    isShowAdd: {
      type: Boolean,
      default: false
    },
    /** 是否支持编辑名称 */
    isEditName: {
      type: Boolean,
      default: false
    },
    /** 是否显示操作按钮 */
    operate: {
      type: Boolean,
      default: false
    },
    /** 是否显示预览按钮 */
    isShowPreviewBtn: {
      type: Boolean,
      default: false
    },
    isShowOpenFlag: {
      type: Boolean,
      default: true
    }
  },
  /** add */
  emits: ['add', 'editName', 'edit', 'delete', 'startClass', 'click'],
  setup(props, { emit }) {
    return () => (
      <div
        class={[
          styles.coursewareType,
          props.isHoverShowAdd
            ? styles.coursewareTypeHover
            : styles.coursewareTypeHocoursewareTypeShow
        ]}>
        {props.isShowAdd && (
          <NButton
            type="primary"
            class={[styles.addBtn]}
            disabled={props.item.isAdd ? true : false}
            onClick={(e: MouseEvent) => {
              e.stopPropagation();
              e.preventDefault();
              emit('add');
            }}>
            {props.item.isAdd ? '已添加' : '添加'}
          </NButton>
        )}
        <div
          class={[styles.cover, props.isShowPreviewBtn && styles.hideP]}
          onClick={() => emit('click')}>
          {props.item.openFlag && props.isShowOpenFlag && (
            <span class={styles.status}>公开</span>
          )}
          <NImage objectFit="cover" previewDisabled src={props.item.coverImg} />

          {props.isShowPreviewBtn && (
            <div class={styles.preview}>
              <NButton strong secondary class={styles.previewBtn}>
                使用课件
              </NButton>
            </div>
          )}
        </div>
        <div class={styles.coursewareText}>
          <div class={[styles.name, props.isEditName && styles.editName]}>
            <span>{props.item.name}</span>
            <i class={styles.iconEditName} onClick={() => emit('editName')}></i>
          </div>
          <div class={styles.subjectName}>{props.item.subjectNames}</div>
        </div>

        {props.operate && (
          <div class={styles.footer}>
            <div class={styles.actionClass} onClick={() => emit('startClass')}>
              开始上课
            </div>
            <NSpace>
              <NTooltip showArrow={false}>
                {{
                  trigger: () => (
                    <div class={styles.optons} onClick={() => emit('edit')}>
                      {/* <NImage src={iconEdit} previewDisabled></NImage> */}
                      <i class={styles.iconEdit}></i>
                    </div>
                  ),
                  default: () => <div>编辑</div>
                }}
              </NTooltip>
              <NTooltip showArrow={false}>
                {{
                  trigger: () => (
                    <div class={styles.optons} onClick={() => emit('delete')}>
                      {/* <NImage src={iconDelete} previewDisabled></NImage> */}
                      <i class={styles.iconDelete}></i>
                    </div>
                  ),
                  default: () => <div>删除</div>
                }}
              </NTooltip>
            </NSpace>
          </div>
        )}
      </div>
    );
  }
});
